TelemetryManager

Struct TelemetryManager 

pub struct TelemetryManager { /* private fields */ }
Telemetry manager

Implementations

Source

impl TelemetryManager

pub fn new(max_metrics: usize) -> Self

Create a new telemetry manager

pub async fn increment_counter( &self, name: &str, value: f64, tags: HashMap<String, String>, )

Record a counter metric

pub async fn set_gauge( &self, name: &str, value: f64, tags: HashMap<String, String>, )

Record a gauge metric

pub async fn record_histogram( &self, name: &str, value: f64, tags: HashMap<String, String>, )

Record a histogram value

pub async fn record_timer( &self, name: &str, duration: Duration, tags: HashMap<String, String>, )

Record a timer metric

pub async fn update_system_health(&self, health: SystemHealth)

Update system health metrics

pub async fn set_active_agents(&self, count: usize)

Update active agent count without overwriting the rest of the health snapshot.

pub async fn set_active_connections(&self, count: usize)

Update active connection count without overwriting the rest of the health snapshot.

pub async fn get_system_health(&self) -> SystemHealth

Get current system health

pub async fn get_recent_metrics(&self, limit: usize) -> Vec<Metric>

Get recent metrics

pub async fn get_metrics_summary(&self) -> MetricsSummary

Get an aggregate snapshot of counters, gauges, histograms, and system health.

pub async fn clear_metrics(&self)

Clear all metrics