pub struct TelemetryManager { /* private fields */ }Expand description
Telemetry manager
Implementations
Sourceimpl TelemetryManager
impl TelemetryManager
Sourcepub async fn increment_counter(
&self,
name: &str,
value: f64,
tags: HashMap<String, String>,
)
pub async fn increment_counter( &self, name: &str, value: f64, tags: HashMap<String, String>, )
Record a counter metric
Sourcepub async fn set_gauge(
&self,
name: &str,
value: f64,
tags: HashMap<String, String>,
)
pub async fn set_gauge( &self, name: &str, value: f64, tags: HashMap<String, String>, )
Record a gauge metric
Sourcepub async fn record_histogram(
&self,
name: &str,
value: f64,
tags: HashMap<String, String>,
)
pub async fn record_histogram( &self, name: &str, value: f64, tags: HashMap<String, String>, )
Record a histogram value
Sourcepub async fn record_timer(
&self,
name: &str,
duration: Duration,
tags: HashMap<String, String>,
)
pub async fn record_timer( &self, name: &str, duration: Duration, tags: HashMap<String, String>, )
Record a timer metric
Sourcepub async fn update_system_health(&self, health: SystemHealth)
pub async fn update_system_health(&self, health: SystemHealth)
Update system health metrics
Sourcepub async fn set_active_agents(&self, count: usize)
pub async fn set_active_agents(&self, count: usize)
Update active agent count without overwriting the rest of the health snapshot.
Sourcepub async fn set_active_connections(&self, count: usize)
pub async fn set_active_connections(&self, count: usize)
Update active connection count without overwriting the rest of the health snapshot.
Sourcepub async fn get_system_health(&self) -> SystemHealth
pub async fn get_system_health(&self) -> SystemHealth
Get current system health
Sourcepub async fn get_recent_metrics(&self, limit: usize) -> Vec<Metric>
pub async fn get_recent_metrics(&self, limit: usize) -> Vec<Metric>
Get recent metrics
Sourcepub async fn get_metrics_summary(&self) -> MetricsSummary
pub async fn get_metrics_summary(&self) -> MetricsSummary
Get an aggregate snapshot of counters, gauges, histograms, and system health.
Sourcepub async fn clear_metrics(&self)
pub async fn clear_metrics(&self)
Clear all metrics